## 更新内容

### 新功能
- 为 ChatUI 添加文件拖拽上传功能 ([#4583](https://github.com/AstrBotDevs/AstrBot/issues/4583))
- 实现人格文件夹以进行高级人格管理 ([#4443](https://github.com/AstrBotDevs/AstrBot/issues/4443))
- 添加人格文件夹管理以支持层级组织 (db)
- 支持 Genie TTS

### 修复
- 增强提供商选择错误处理和日志记录，避免出现 `Provider 不是 Provider 类型` 的错误 ([#4654](https://github.com/AstrBotDevs/AstrBot/issues/4654))
- aiocqhttp 适配器中的 Markdown KeyError 或 UnboundLocalError 问题 ([#4656](https://github.com/AstrBotDevs/AstrBot/issues/4656))
- 确保 providers 中的 embedding 维度作为整数返回 ([#4547](https://github.com/AstrBotDevs/AstrBot/issues/4547))
- 钉钉流式响应问题 ([#4590](https://github.com/AstrBotDevs/AstrBot/issues/4590))
- 提供商选择按钮被长模型名称遮挡的问题 ([#4631](https://github.com/AstrBotDevs/AstrBot/issues/4631))
- 更新 `web_search_tavily` 处理，避免在非 ChatUI 平台出现信息引用 ([#4633](https://github.com/AstrBotDevs/AstrBot/issues/4633))

### 性能优化
- T2I 模板编辑器预览 ([#4574](https://github.com/AstrBotDevs/AstrBot/issues/4574))

### 杂项
- 移除已弃用的 `tool` 命令
